/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface IntegrationConfluentResourceConfig extends cdktf.TerraformMetaArguments {
    /**
    * Confluent Account ID.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.25.0/docs/resources/integration_confluent_resource#account_id IntegrationConfluentResource#account_id}
    */
    readonly accountId: string;
    /**
    * The ID associated with a Confluent resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.25.0/docs/resources/integration_confluent_resource#resource_id IntegrationConfluentResource#resource_id}
    */
    readonly resourceId: string;
    /**
    * The resource type of the Resource. Can be `kafka`, `connector`, `ksql`, or `schema_registry`.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.25.0/docs/resources/integration_confluent_resource#resource_type IntegrationConfluentResource#resource_type}
    */
    readonly resourceType?: string;
    /**
    * A list of strings representing tags. Can be a single key, or key-value pairs separated by a colon.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.25.0/docs/resources/integration_confluent_resource#tags IntegrationConfluentResource#tags}
    */
    readonly tags?: string[];
}
/**
* Represents a {@link https://registry.terraform.io/providers/datadog/datadog/3.25.0/docs/resources/integration_confluent_resource datadog_integration_confluent_resource}
*/
export declare class IntegrationConfluentResource extends cdktf.TerraformResource {
    static readonly tfResourceType = "datadog_integration_confluent_resource";
    /**
    * Create a new {@link https://registry.terraform.io/providers/datadog/datadog/3.25.0/docs/resources/integration_confluent_resource datadog_integration_confluent_resource} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options IntegrationConfluentResourceConfig
    */
    constructor(scope: Construct, id: string, config: IntegrationConfluentResourceConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    get id(): string;
    private _resourceId?;
    get resourceId(): string;
    set resourceId(value: string);
    get resourceIdInput(): string | undefined;
    private _resourceType?;
    get resourceType(): string;
    set resourceType(value: string);
    resetResourceType(): void;
    get resourceTypeInput(): string | undefined;
    private _tags?;
    get tags(): string[];
    set tags(value: string[]);
    resetTags(): void;
    get tagsInput(): string[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
